@@ -68,6 +68,8 @@ Later updates (from the source web site):
 
 =item * version 0.91, published on September 11, 2006
 
+=item * version 0.92, published on September 18, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -112,3 +114,4 @@ patty smokin_jim betty_the_bulldozer
 amber_dextrous stinky_pete 
 phil_o_dendron
 steve
+lyin_john
