@@ -46,6 +46,8 @@ Further updates:
 
 =item * version 0.95, published on October 9, 2006
 
+=item * version 0.96, published on October 16, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -604,6 +606,7 @@ BITS
 BIWILLIA
 BJEPS
 BJKUIT
+BJM
 BJOERN
 BJORNARDO
 BJR
@@ -2016,6 +2019,7 @@ HIKARINE
 HIMAZU
 HIO
 HIRO
+HIROSE
 HIROYUKI
 HISELDL
 HITHERTO
@@ -2724,10 +2728,12 @@ KALNINS
 KALT
 KAMENSKY
 KAMILLO
+KAMO
 KANE
 KANEY
 KANEZENG
 KANNA
+KAORU
 KAPPA
 KARASIK
 KARDEL
@@ -3053,6 +3059,7 @@ LPALMER
 LPETERS
 LREEVES
 LROCHER
+LSIM
 LSLOAN
 LSTAF
 LTBOOTS
@@ -3091,6 +3098,7 @@ MACDEE
 MACFLY
 MACGYVER
 MACIEJ
+MACKENZIE
 MACKERS
 MADCODER
 MADGHOUL
@@ -3188,6 +3196,7 @@ MARTY
 MARTYLOO
 MARTYNOFF
 MARZOA
+MASAHITO
 MASAHJI
 MASANORIH
 MASAP
@@ -3418,6 +3427,7 @@ MJM
 MJP
 MJR
 MJS
+MKAL
 MKENNEDY
 MKHRAPOV
 MKMUELLER
@@ -3657,6 +3667,7 @@ NFMNUNES
 NGEREN
 NGLEDHILL
 NHARALE
+NIBZE
 NICK
 NICKB
 NICKBAKER
@@ -4205,6 +4216,7 @@ RFOLEY
 RFRANKEL
 RGARCIA
 RGARTON
+RGC
 RGEOFFREY
 RGIBSON
 RGIERSIG
@@ -4242,6 +4254,7 @@ RICKM
 RIFFER
 RIGBYC
 RIIKI
+RIJK
 RIK
 RIOS
 RIPENCC
@@ -4750,6 +4763,7 @@ SPANNRING
 SPARKS
 SPARSONS
 SPATOCS
+SPAULGER
 SPDITNER
 SPECTRUM
 SPEEVES
@@ -4904,6 +4918,7 @@ SWILLIAM
 SWMCC
 SWMCD
 SWORDSMAN
+SWSLADE
 SYAMAL
 SYMX
 SYNEDRA
@@ -5116,6 +5131,7 @@ TROXEL
 TROYP
 TRUESDALE
 TRUSTCOM
+TRYM
 TRZ
 TSANDERS
 TSANGTC
